# ardj: internet radio software

ardj is a software to operate an internet radio in automatic mode. It uses icecast and ezstream internally to broadcast your music using a playlist, which can be a simple shuffle, or a complicated setup with time slots, jingles and pre-rolls.

Optionally it can send your playback history to last.fm or libre.fm.

Distributed under the GNU GPL.

## Features

- Simple installation. Configures icecast and ezstream for you.
- Simple web interface to control playback.
- Highly configurable automatic playlists.
- Jingles, prerolls, different playlists based on time and day.
- Manual control for short time playback.
- Execute shell scripts on program change.
- ReplayGain is automatically calculated for all uploaded music.
- Some default music to start broadcasting out of the box.
- Scrobble tracks using last.fm or libre.fm.

## User manual

- Installing
- Automatic playlists
- Manual playlists
- Playback queue

## Links

- Source code (Mercurial)
- Online docs
- PIP repo
- Example running station (defunct)

## Authors

Parts of this software were written by:

- Justin Forest (hex@umonkey.net)
- Hakimov Irik (hakimovis@gmail.com)
- Kaener Vora (k43n3r@gmail.com)